{% extends "django_classified/_base.html" %}

{% block title %}{{ DCF.SITE_NAME }}{% endblock title %}

{% block body %}
  <div class="row marketing">
    {% for object in object_list %}
      <div class="col-md-3">
        <h4 id="{{ object.section.0.id }}">{{ object.section.0 }} [{{ object.section.1 }}]</h4>
        {% for group, group_count in object.groups %}
          {% if group_count > 0 or DCF.DISPLAY_EMPTY_GROUPS %}
            <a href='{{ group.get_absolute_url }}' title="{{ group.title }}">
              {{ group.title }}&nbsp;[{{ group_count }}]<br/>
            </a>
          {% endif %}
        {% endfor %}
      </div>
    {% endfor %}
  </div>
{% endblock %}