{% load i18n %}

{% if user.is_superuser %}
  <div class="row">
    <div class="col-lg-12">
      <a href='{% url 'django_classified:my-delete' item.pk %}' class="btn btn-danger">
        {% trans "Delete" %}
      </a>
      <a href='{% url 'django_classified:item-edit' item.pk %}' class="btn btn-default">
        {% trans "Edit" %}
      </a>
    </div>
  </div>
{% endif %}