# Generated by Django 2.0.7 on 2018-07-17 11:07

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('django_classified', '0002_auto_20180713_2158'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='is_active',
            field=models.BooleanField(db_index=True, default=True, verbose_name='active'),
        ),
        migrations.AlterField(
            model_name='profile',
            name='phone',
            field=models.CharField(blank=True, max_length=30, null=True, verbose_name='Contact phone'),
        ),
    ]
