{% extends "django_classified/_base.html" %}

{% block title %}{{ object }}{% endblock %}

{% block body %}
  <div class="row">
    <div class="col-lg-12">
      <h4>
        <a href="{% url 'django_classified:index' %}#{{ object.section.id }}">{{ object.section }}</a> > <a
              href="{{ object.get_absolute_url }}" title="{{ object.title }}">
          {{ object.title }}
        </a>
      </h4>
    </div>
  </div>

  <div class="row">
    <div class="col-lg-12">
      {% include "django_classified/item_list.inc.html" %}
    </div>
  </div>

  <div class="row">
    <div class="col-lg-12">
      {% include "django_classified/list_pagination.inc.html" %}
    </div>
  </div>
{% endblock body %}